Mantine @mantine/spotlight 9.5.0 wrappers (generated, supplement hoisted from codegen/supplements/).
Mantine @mantine/spotlight 9.5.0 wrappers (generated, supplement hoisted from codegen/supplements/).
(close)Close the spotlight command palette.
Close the spotlight command palette.
(open)Open the spotlight command palette (single default instance).
Open the spotlight command palette (single default instance).
Spotlight — Command center for your application
https://mantine.dev/x/spotlight
Props (docgen 9.5.0):
SpotlightActions[] (required) — Actions data, passed down to Spotlight.Action componentboolean (default false) — If set, the modal is centered verticallyReact.ReactNode — Modal contentboolean (default true) — Determines whether the search query should be cleared when the spotlight is closedboolean (default true) — Determines whether spotlight should be closed when one of the actions is triggeredboolean (default true) — If set, the modal/drawer is closed when user clicks on the overlayboolean (default true) — If set, onClose is called when user presses the escape keyboolean — If set, spotlight will not be renderedSpotlightFilterFunction — Function to filter actions data based on search query, by default actions are filtered by title, description and keywordsboolean — Forces opened state, useful for testsboolean (default false) — If set, the modal takes the entire screenboolean (default false) — Determines whether search query should be highlighted in action labelstring — Id used to connect modal/drawer with body and titleboolean (default false) — If set modal/drawer is not unmounted from the DOM when hidden. display: none styles are applied instead."activity" | "display-none" (default 'activity') — Controls how the modal/drawer is hidden when keepMounted is set: 'activity' - hidden with React 19 Activity component, 'display-none' - hidden with display: none stylesnumber (default Infinity) — Maximum number of actions displayed at a timeboolean (default true) — If set, scroll is locked when opened={true}MaxHeight<string | number> (default 400) — Spotlight content max-height. Ignored unless scrollable prop is set.React.ReactNode — Message displayed when none of the actions match given filter() => void — Called when enter transition ends() => void — Called when exit transition ends(query: string) => void — Called when query changes() => void — Called when spotlight closes() => void — Called when spotlight opensModalBaseOverlayProps — Props passed down to the Overlay component, use to configure opacity, background-color, styles and other propertiesMantineSpacing (default 'md') — Key of theme.spacing or any valid CSS value to set content, header and footer paddingBasePortalProps — Props passed down to the Portal component when withinPortal is setstring — Controlled Spotlight search queryMantineRadius | number (default theme.defaultRadius) — Key of theme.radius or any valid CSS value to set border-radiusRemoveScrollProps — Props passed down to react-remove-scroll, can be used to customize scroll lock behaviorboolean (default true) — If set, focus is returned to the last active element when onClose is calledScrollAreaComponent (default 'div') — Scroll area componentPartial<ScrollAreaAutosizeProps> — Props passed down to the ScrollArea componentboolean (default false) — Determines whether the actions list should be scrollable. If not set, maxHeight is ignoredSpotlightSearchProps — Props passed down to the Spotlight.SearchMantineShadow (default 'xl') — Key of theme.shadows or any valid CSS box-shadow valuestring | string[] | null (default 'mod + K') — Keyboard shortcut or a list of shortcuts to trigger spotlightMantineSize | number (default 'md') — Controls width of the content areastring — Id of the modal in the Modal.StackSpotlightStore — Spotlight store, can be used to create multiple instances of spotlightstring[] (default ['input', 'textarea', 'select']) — A list of tags which when focused will be ignored by shortcutReact.ReactNode — Modal titleTransitionProps — Props added to the Transition component that used to animate overlay and body, use to configure duration and animation type, { duration: 200, transition: 'fade-down' } by defaultboolean (default true) — If set, focus is trapped within the modal/drawerboolean (default false) — Determines whether shortcut should trigger based in contentEditableboolean (default true) — If set, the overlay is renderedboolean (default true) — If set, the component is rendered inside PortalMarginLeft<string | number> (default 5vw) — Left/right modal offsetMarginTop<string | number> (default 5dvh) — Top/bottom modal offsetstring | number (default 200) — z-index CSS property of the root elementOptional leading props map; remaining args are children.
Spotlight — Command center for your application
https://mantine.dev/x/spotlight
Props (docgen 9.5.0):
- **actions** `SpotlightActions[]` **(required)** — Actions data, passed down to `Spotlight.Action` component
- **centered** `boolean` _(default `false`)_ — If set, the modal is centered vertically
- **children** `React.ReactNode` — Modal content
- **clearQueryOnClose** `boolean` _(default `true`)_ — Determines whether the search query should be cleared when the spotlight is closed
- **closeOnActionTrigger** `boolean` _(default `true`)_ — Determines whether spotlight should be closed when one of the actions is triggered
- **closeOnClickOutside** `boolean` _(default `true`)_ — If set, the modal/drawer is closed when user clicks on the overlay
- **closeOnEscape** `boolean` _(default `true`)_ — If set, `onClose` is called when user presses the escape key
- **disabled** `boolean` — If set, spotlight will not be rendered
- **filter** `SpotlightFilterFunction` — Function to filter actions data based on search query, by default actions are filtered by title, description and keywords
- **forceOpened** `boolean` — Forces opened state, useful for tests
- **fullScreen** `boolean` _(default `false`)_ — If set, the modal takes the entire screen
- **highlightQuery** `boolean` _(default `false`)_ — Determines whether search query should be highlighted in action label
- **id** `string` — Id used to connect modal/drawer with body and title
- **keepMounted** `boolean` _(default `false`)_ — If set modal/drawer is not unmounted from the DOM when hidden. `display: none` styles are applied instead.
- **keepMountedMode** `"activity" | "display-none"` _(default `'activity'`)_ — Controls how the modal/drawer is hidden when `keepMounted` is set: `'activity'` - hidden with React 19 `Activity` component, `'display-none'` - hidden with `display: none` styles
- **limit** `number` _(default `Infinity`)_ — Maximum number of actions displayed at a time
- **lockScroll** `boolean` _(default `true`)_ — If set, scroll is locked when `opened={true}`
- **maxHeight** `MaxHeight<string | number>` _(default `400`)_ — Spotlight content max-height. Ignored unless `scrollable` prop is set.
- **nothingFound** `React.ReactNode` — Message displayed when none of the actions match given `filter`
- **onEnterTransitionEnd** `() => void` — Called when enter transition ends
- **onExitTransitionEnd** `() => void` — Called when exit transition ends
- **onQueryChange** `(query: string) => void` — Called when query changes
- **onSpotlightClose** `() => void` — Called when spotlight closes
- **onSpotlightOpen** `() => void` — Called when spotlight opens
- **overlayProps** `ModalBaseOverlayProps` — Props passed down to the `Overlay` component, use to configure opacity, `background-color`, styles and other properties
- **padding** `MantineSpacing` _(default `'md'`)_ — Key of `theme.spacing` or any valid CSS value to set content, header and footer padding
- **portalProps** `BasePortalProps` — Props passed down to the Portal component when `withinPortal` is set
- **query** `string` — Controlled Spotlight search query
- **radius** `MantineRadius | number` _(default `theme.defaultRadius`)_ — Key of `theme.radius` or any valid CSS value to set `border-radius`
- **removeScrollProps** `RemoveScrollProps` — Props passed down to react-remove-scroll, can be used to customize scroll lock behavior
- **returnFocus** `boolean` _(default `true`)_ — If set, focus is returned to the last active element when `onClose` is called
- **scrollAreaComponent** `ScrollAreaComponent` _(default `'div'`)_ — Scroll area component
- **scrollAreaProps** `Partial<ScrollAreaAutosizeProps>` — Props passed down to the `ScrollArea` component
- **scrollable** `boolean` _(default `false`)_ — Determines whether the actions list should be scrollable. If not set, `maxHeight` is ignored
- **searchProps** `SpotlightSearchProps` — Props passed down to the `Spotlight.Search`
- **shadow** `MantineShadow` _(default `'xl'`)_ — Key of `theme.shadows` or any valid CSS box-shadow value
- **shortcut** `string | string[] | null` _(default `'mod + K'`)_ — Keyboard shortcut or a list of shortcuts to trigger spotlight
- **size** `MantineSize | number` _(default `'md'`)_ — Controls width of the content area
- **stackId** `string` — Id of the modal in the `Modal.Stack`
- **store** `SpotlightStore` — Spotlight store, can be used to create multiple instances of spotlight
- **tagsToIgnore** `string[]` _(default `['input', 'textarea', 'select']`)_ — A list of tags which when focused will be ignored by shortcut
- **title** `React.ReactNode` — Modal title
- **transitionProps** `TransitionProps` — Props added to the `Transition` component that used to animate overlay and body, use to configure duration and animation type, `{ duration: 200, transition: 'fade-down' }` by default
- **trapFocus** `boolean` _(default `true`)_ — If set, focus is trapped within the modal/drawer
- **triggerOnContentEditable** `boolean` _(default `false`)_ — Determines whether shortcut should trigger based in contentEditable
- **withOverlay** `boolean` _(default `true`)_ — If set, the overlay is rendered
- **withinPortal** `boolean` _(default `true`)_ — If set, the component is rendered inside `Portal`
- **xOffset** `MarginLeft<string | number>` _(default `5vw`)_ — Left/right modal offset
- **yOffset** `MarginTop<string | number>` _(default `5dvh`)_ — Top/bottom modal offset
- **zIndex** `string | number` _(default `200`)_ — `z-index` CSS property of the root element
Optional leading props map; remaining args are children.SpotlightAction — Command center for your application (Spotlight family)
https://mantine.dev/x/spotlight
Props (docgen 9.5.0):
React.ReactNode — Children override default action elements, if passed, label, description and sections are hiddenboolean — Determines whether the spotlight should be closed when action is triggered, overrides closeOnActionTrigger prop set on Spotlightstring — Action description, pass string to use in default filterboolean (default true) — Determines whether left and right sections should have dimmed stylesMantineColor (default 'yellow') — Key of theme.colors of any valid CSS color that will be used to highlight search queryboolean (default false) — Determines whether search query should be highlighted in action labelstring | string[] — Keywords that are used for default filtering, not displayed anywhere, can be a string: "react,router,javascript" or an array: ['react', 'router', 'javascript']string — Action label, pass string to use in default filterReact.ReactNode — Section displayed on the left side of the label, for example, iconReact.ReactNode — Section displayed on the right side of the label, for example, hotkeyOptional leading props map; remaining args are children.
SpotlightAction — Command center for your application (Spotlight family) https://mantine.dev/x/spotlight Props (docgen 9.5.0): - **children** `React.ReactNode` — Children override default action elements, if passed, label, description and sections are hidden - **closeSpotlightOnTrigger** `boolean` — Determines whether the spotlight should be closed when action is triggered, overrides `closeOnActionTrigger` prop set on `Spotlight` - **description** `string` — Action description, pass string to use in default filter - **dimmedSections** `boolean` _(default `true`)_ — Determines whether left and right sections should have dimmed styles - **highlightColor** `MantineColor` _(default `'yellow'`)_ — Key of `theme.colors` of any valid CSS color that will be used to highlight search query - **highlightQuery** `boolean` _(default `false`)_ — Determines whether search query should be highlighted in action label - **keywords** `string | string[]` — Keywords that are used for default filtering, not displayed anywhere, can be a string: "react,router,javascript" or an array: ['react', 'router', 'javascript'] - **label** `string` — Action label, pass string to use in default filter - **leftSection** `React.ReactNode` — Section displayed on the left side of the label, for example, icon - **rightSection** `React.ReactNode` — Section displayed on the right side of the label, for example, hotkey Optional leading props map; remaining args are children.
SpotlightActionsGroup — Command center for your application (Spotlight family)
https://mantine.dev/x/spotlight
Props (docgen 9.5.0):
React.ReactNode — Spotlight.Action componentsstring — Group labelOptional leading props map; remaining args are children.
SpotlightActionsGroup — Command center for your application (Spotlight family) https://mantine.dev/x/spotlight Props (docgen 9.5.0): - **children** `React.ReactNode` — `Spotlight.Action` components - **label** `string` — Group label Optional leading props map; remaining args are children.
Spotlight.ActionsList — compound part of Spotlight (docgen omits it). Optional leading props map; remaining args are children.
Spotlight.ActionsList — compound part of Spotlight (docgen omits it). Optional leading props map; remaining args are children.
Spotlight.Empty — compound part of Spotlight (docgen omits it). Optional leading props map; remaining args are children.
Spotlight.Empty — compound part of Spotlight (docgen omits it). Optional leading props map; remaining args are children.
Spotlight.Footer — compound part of Spotlight (docgen omits it). Optional leading props map; remaining args are children.
Spotlight.Footer — compound part of Spotlight (docgen omits it). Optional leading props map; remaining args are children.
SpotlightRoot — Command center for your application (Spotlight family)
https://mantine.dev/x/spotlight
Props (docgen 9.5.0):
boolean (default false) — If set, the modal is centered verticallyReact.ReactNode — Modal contentboolean (default true) — Determines whether the search query should be cleared when the spotlight is closedboolean (default true) — Determines whether spotlight should be closed when one of the actions is triggeredboolean (default true) — If set, the modal/drawer is closed when user clicks on the overlayboolean (default true) — If set, onClose is called when user presses the escape keyboolean — If set, spotlight will not be renderedboolean — Forces opened state, useful for testsboolean (default false) — If set, the modal takes the entire screenstring — Id used to connect modal/drawer with body and titleboolean (default false) — If set modal/drawer is not unmounted from the DOM when hidden. display: none styles are applied instead."activity" | "display-none" (default 'activity') — Controls how the modal/drawer is hidden when keepMounted is set: 'activity' - hidden with React 19 Activity component, 'display-none' - hidden with display: none stylesboolean (default true) — If set, scroll is locked when opened={true}MaxHeight<string | number> (default 400) — Spotlight content max-height. Ignored unless scrollable prop is set.() => void — Called when enter transition ends() => void — Called when exit transition ends(query: string) => void — Called when query changes() => void — Called when spotlight closes() => void — Called when spotlight opensModalBaseOverlayProps — Props passed down to the Overlay component, use to configure opacity, background-color, styles and other propertiesMantineSpacing (default 'md') — Key of theme.spacing or any valid CSS value to set content, header and footer paddingBasePortalProps — Props passed down to the Portal component when withinPortal is setstring — Controlled Spotlight search queryMantineRadius | number (default theme.defaultRadius) — Key of theme.radius or any valid CSS value to set border-radiusRemoveScrollProps — Props passed down to react-remove-scroll, can be used to customize scroll lock behaviorboolean (default true) — If set, focus is returned to the last active element when onClose is calledScrollAreaComponent (default 'div') — Scroll area componentboolean (default false) — Determines whether the actions list should be scrollable. If not set, maxHeight is ignoredMantineShadow (default 'xl') — Key of theme.shadows or any valid CSS box-shadow valuestring | string[] | null (default 'mod + K') — Keyboard shortcut or a list of shortcuts to trigger spotlightMantineSize | number (default 'md') — Controls width of the content areastring — Id of the modal in the Modal.StackSpotlightStore — Spotlight store, can be used to create multiple instances of spotlightstring[] (default ['input', 'textarea', 'select']) — A list of tags which when focused will be ignored by shortcutReact.ReactNode — Modal titleTransitionProps — Props added to the Transition component that used to animate overlay and body, use to configure duration and animation type, { duration: 200, transition: 'fade-down' } by defaultboolean (default true) — If set, focus is trapped within the modal/drawerboolean (default false) — Determines whether shortcut should trigger based in contentEditableboolean (default true) — If set, the overlay is renderedboolean (default true) — If set, the component is rendered inside PortalMarginLeft<string | number> (default 5vw) — Left/right modal offsetMarginTop<string | number> (default 5dvh) — Top/bottom modal offsetstring | number (default 200) — z-index CSS property of the root elementOptional leading props map; remaining args are children.
SpotlightRoot — Command center for your application (Spotlight family)
https://mantine.dev/x/spotlight
Props (docgen 9.5.0):
- **centered** `boolean` _(default `false`)_ — If set, the modal is centered vertically
- **children** `React.ReactNode` — Modal content
- **clearQueryOnClose** `boolean` _(default `true`)_ — Determines whether the search query should be cleared when the spotlight is closed
- **closeOnActionTrigger** `boolean` _(default `true`)_ — Determines whether spotlight should be closed when one of the actions is triggered
- **closeOnClickOutside** `boolean` _(default `true`)_ — If set, the modal/drawer is closed when user clicks on the overlay
- **closeOnEscape** `boolean` _(default `true`)_ — If set, `onClose` is called when user presses the escape key
- **disabled** `boolean` — If set, spotlight will not be rendered
- **forceOpened** `boolean` — Forces opened state, useful for tests
- **fullScreen** `boolean` _(default `false`)_ — If set, the modal takes the entire screen
- **id** `string` — Id used to connect modal/drawer with body and title
- **keepMounted** `boolean` _(default `false`)_ — If set modal/drawer is not unmounted from the DOM when hidden. `display: none` styles are applied instead.
- **keepMountedMode** `"activity" | "display-none"` _(default `'activity'`)_ — Controls how the modal/drawer is hidden when `keepMounted` is set: `'activity'` - hidden with React 19 `Activity` component, `'display-none'` - hidden with `display: none` styles
- **lockScroll** `boolean` _(default `true`)_ — If set, scroll is locked when `opened={true}`
- **maxHeight** `MaxHeight<string | number>` _(default `400`)_ — Spotlight content max-height. Ignored unless `scrollable` prop is set.
- **onEnterTransitionEnd** `() => void` — Called when enter transition ends
- **onExitTransitionEnd** `() => void` — Called when exit transition ends
- **onQueryChange** `(query: string) => void` — Called when query changes
- **onSpotlightClose** `() => void` — Called when spotlight closes
- **onSpotlightOpen** `() => void` — Called when spotlight opens
- **overlayProps** `ModalBaseOverlayProps` — Props passed down to the `Overlay` component, use to configure opacity, `background-color`, styles and other properties
- **padding** `MantineSpacing` _(default `'md'`)_ — Key of `theme.spacing` or any valid CSS value to set content, header and footer padding
- **portalProps** `BasePortalProps` — Props passed down to the Portal component when `withinPortal` is set
- **query** `string` — Controlled Spotlight search query
- **radius** `MantineRadius | number` _(default `theme.defaultRadius`)_ — Key of `theme.radius` or any valid CSS value to set `border-radius`
- **removeScrollProps** `RemoveScrollProps` — Props passed down to react-remove-scroll, can be used to customize scroll lock behavior
- **returnFocus** `boolean` _(default `true`)_ — If set, focus is returned to the last active element when `onClose` is called
- **scrollAreaComponent** `ScrollAreaComponent` _(default `'div'`)_ — Scroll area component
- **scrollable** `boolean` _(default `false`)_ — Determines whether the actions list should be scrollable. If not set, `maxHeight` is ignored
- **shadow** `MantineShadow` _(default `'xl'`)_ — Key of `theme.shadows` or any valid CSS box-shadow value
- **shortcut** `string | string[] | null` _(default `'mod + K'`)_ — Keyboard shortcut or a list of shortcuts to trigger spotlight
- **size** `MantineSize | number` _(default `'md'`)_ — Controls width of the content area
- **stackId** `string` — Id of the modal in the `Modal.Stack`
- **store** `SpotlightStore` — Spotlight store, can be used to create multiple instances of spotlight
- **tagsToIgnore** `string[]` _(default `['input', 'textarea', 'select']`)_ — A list of tags which when focused will be ignored by shortcut
- **title** `React.ReactNode` — Modal title
- **transitionProps** `TransitionProps` — Props added to the `Transition` component that used to animate overlay and body, use to configure duration and animation type, `{ duration: 200, transition: 'fade-down' }` by default
- **trapFocus** `boolean` _(default `true`)_ — If set, focus is trapped within the modal/drawer
- **triggerOnContentEditable** `boolean` _(default `false`)_ — Determines whether shortcut should trigger based in contentEditable
- **withOverlay** `boolean` _(default `true`)_ — If set, the overlay is rendered
- **withinPortal** `boolean` _(default `true`)_ — If set, the component is rendered inside `Portal`
- **xOffset** `MarginLeft<string | number>` _(default `5vw`)_ — Left/right modal offset
- **yOffset** `MarginTop<string | number>` _(default `5dvh`)_ — Top/bottom modal offset
- **zIndex** `string | number` _(default `200`)_ — `z-index` CSS property of the root element
Optional leading props map; remaining args are children.SpotlightSearch — Command center for your application (Spotlight family)
https://mantine.dev/x/spotlight
Props (docgen 9.5.0):
boolean — Sets disabled attribute on the input elementReact.ReactNode — Determines whether the input should have error styles and aria-invalid attributestring — Input element idstring — HTML size attribute for the input element (number of visible characters)React.ReactNode — Content section displayed on the left side of the inputReact.CSSProperties["pointerEvents"] (default 'none') — Sets pointer-events styles on the leftSection element. Use 'all' when section contains interactive elements (buttons, links).React.ComponentProps<"div"> — Props passed down to the leftSection elementReact.CSSProperties["width"] — Left section width, used to set width of the section and input padding-left, by default equals to the input heightboolean (default false) — Displays loading indicator in the left or right section"left" | "right" (default 'right') — Position of the loading indicatorboolean (default false) — Adjusts padding and sizing calculations for multiline inputs (use with component="textarea"). Does not make the input multiline by itself.boolean (default false) — Determines whether the input should have cursor: pointer style. Use when input acts as a button-like trigger (e.g., component="button" for Select/DatePicker).MantineRadius | number (default theme.defaultRadius) — Key of theme.radius or any valid CSS value to set border-radius, numbers are converted to remboolean — Sets required attribute on the input elementReact.ReactNode — Content section displayed on the right side of the inputReact.CSSProperties["pointerEvents"] (default 'none') — Sets pointer-events styles on the rightSection element. Use 'all' when section contains interactive elements (buttons, links).React.ComponentProps<"div"> — Props passed down to the rightSection elementReact.CSSProperties["width"] — Right section width, used to set width of the section and input padding-right, by default equals to the input heightRef<HTMLDivElement> — Root element refMantineSize (default 'sm') — Controls input height, horizontal padding, and font-sizeReact.ReactNode — Determines whether the input should have success stylesboolean (default true) — Determines whether aria- and other accessibility attributes should be added to the input. Only disable when implementing custom accessibility handling.boolean (default true) — Determines whether the input should have red border and red text color when the error prop is setboolean (default true) — Determines whether the input should have green border when the success prop is setWrapperProps — Props passed down to the root element of the Input componentOptional leading props map; remaining args are children.
SpotlightSearch — Command center for your application (Spotlight family) https://mantine.dev/x/spotlight Props (docgen 9.5.0): - **disabled** `boolean` — Sets `disabled` attribute on the `input` element - **error** `React.ReactNode` — Determines whether the input should have error styles and `aria-invalid` attribute - **id** `string` — Input element id - **inputSize** `string` — HTML `size` attribute for the input element (number of visible characters) - **leftSection** `React.ReactNode` — Content section displayed on the left side of the input - **leftSectionPointerEvents** `React.CSSProperties["pointerEvents"]` _(default `'none'`)_ — Sets `pointer-events` styles on the `leftSection` element. Use `'all'` when section contains interactive elements (buttons, links). - **leftSectionProps** `React.ComponentProps<"div">` — Props passed down to the `leftSection` element - **leftSectionWidth** `React.CSSProperties["width"]` — Left section width, used to set `width` of the section and input `padding-left`, by default equals to the input height - **loading** `boolean` _(default `false`)_ — Displays loading indicator in the left or right section - **loadingPosition** `"left" | "right"` _(default `'right'`)_ — Position of the loading indicator - **multiline** `boolean` _(default `false`)_ — Adjusts padding and sizing calculations for multiline inputs (use with `component="textarea"`). Does not make the input multiline by itself. - **pointer** `boolean` _(default `false`)_ — Determines whether the input should have `cursor: pointer` style. Use when input acts as a button-like trigger (e.g., `component="button"` for Select/DatePicker). - **radius** `MantineRadius | number` _(default `theme.defaultRadius`)_ — Key of `theme.radius` or any valid CSS value to set `border-radius`, numbers are converted to rem - **required** `boolean` — Sets `required` attribute on the `input` element - **rightSection** `React.ReactNode` — Content section displayed on the right side of the input - **rightSectionPointerEvents** `React.CSSProperties["pointerEvents"]` _(default `'none'`)_ — Sets `pointer-events` styles on the `rightSection` element. Use `'all'` when section contains interactive elements (buttons, links). - **rightSectionProps** `React.ComponentProps<"div">` — Props passed down to the `rightSection` element - **rightSectionWidth** `React.CSSProperties["width"]` — Right section width, used to set `width` of the section and input `padding-right`, by default equals to the input height - **rootRef** `Ref<HTMLDivElement>` — Root element ref - **size** `MantineSize` _(default `'sm'`)_ — Controls input `height`, horizontal `padding`, and `font-size` - **success** `React.ReactNode` — Determines whether the input should have success styles - **withAria** `boolean` _(default `true`)_ — Determines whether `aria-` and other accessibility attributes should be added to the input. Only disable when implementing custom accessibility handling. - **withErrorStyles** `boolean` _(default `true`)_ — Determines whether the input should have red border and red text color when the `error` prop is set - **withSuccessStyles** `boolean` _(default `true`)_ — Determines whether the input should have green border when the `success` prop is set - **wrapperProps** `WrapperProps` — Props passed down to the root element of the `Input` component Optional leading props map; remaining args are children.
(toggle)Toggle the spotlight command palette open/closed.
Toggle the spotlight command palette open/closed.
Reactive hook over the default spotlight store. Raw passthrough: returns the raw JS spotlight store value (read via interop: .-opened, .-open, ...).
Reactive hook over the default spotlight store. Raw passthrough: returns the raw JS spotlight store value (read via interop: .-opened, .-open, ...).
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |